REPR-UTIL
---------
A toolkit to quickly display elements in tools like `jupyter`_ by building upon `ipython rich display`_.

Contributions are appreciated.

.. _`ipython rich display`: https://ipython.readthedocs.io/
.. _`jupyter`: https://jupyter.org/
